/* file csp-debug.h
 *
 * NIST PIV Demo CSP -- Cryptographic Service Provider
 *
 * Designed and Developed by Electrosoft (www.electrosoft-inc.com) based on requirements
 * from the National Institute of Standards and Technology (NIST).
 *
 * This file codes and documents all the necessary debug functions.
 *
 * Adapted from work of Romain Chantereau <rchantereau@entrouvert.com> (CSP11 code)
 */
#ifndef _CSP_DEBUG_H_
#define UNICODE
#define _CSP_DEBUG_H_       /**< csp11.h inclusion tag. */
#ifdef __cplusplus
extern "C" {
#endif

#define DEBUG_FILE      "C:\\escsp.log" /**< Path to the debug log file.*/

#define DEBUG_LEVEL      4  /**< Debug level 0 to 5 */

/** \brief Close the debug log file.
 *
 * \return TRUE if the log file was closed. FALSE if not, (not opened of worse).
 */
BOOL closeDebug();

/** \brief Write debug to file
 *
 *  Lock the debug file, open it, write in it, close it, unlock it.
 *
 *  \param  message C string containgin the message to write.
 *
 *  \return TRUE if ok.
 */
BOOL    fdebug(const char *message);
BOOL    fdebug2(const char *message, int len);

/** \brief Debug macro
 *
 *
 */
#define DEBUG(LEVEL, MESSAGE) \
    if(LEVEL <= DEBUG_LEVEL) \
    { \
        fdebug(MESSAGE); \
    }

#define DEBUG2(LEVEL, MESSAGE, LEN) \
    if(LEVEL <= DEBUG_LEVEL) \
    { \
        fdebug2(MESSAGE, LEN); \
    }

#ifdef __cplusplus
}
#endif
#endif // _CSP_DEBUG_H_

